==> rax-1.1.1.tgz: package/es/vdom/fragment.js <==
function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

import Host from './host';
import NativeComponent from './native';
import Instance from './instance';
import toArray from '../toArray';
import { INSTANCE, INTERNAL, NATIVE_NODE } from '../constant';
/**
 * Fragment Component
 */

var FragmentComponent =
/*#__PURE__*/
function (_NativeComponent) {
  _inheritsLoose(FragmentComponent, _NativeComponent);

  function FragmentComponent() {
    return _NativeComponent.apply(this, arguments) || this;
  }

  var _proto = FragmentComponent.prototype;

  _proto.__mountComponent = function __mountComponent(parent, parentInstance, context, nativeNodeMounter) {
    this.__initComponent(parent, parentInstance, context);

    var instance = this[INSTANCE] = {};
    instance[INTERNAL] = this; // Mount children

    this.__mountChildren(this.__currentElement, context);

    var fragment = this.__getNativeNode();

    if (nativeNodeMounter) {
      nativeNodeMounter(fragment, parent);
    } else {
      for (var i = 0; i < fragment.length; i++) {
        Host.driver.appendChild(fragment[i], parent);
      }
    }

    if (process.env.NODE_ENV !== 'production') {
      this.__currentElement.type = FragmentComponent;
      Host.reconciler.mountComponent(this);
    }

    return instance;
  };

  _proto.__mountChildren = function __mountChildren(children, context) {
    var fragment = this.__getNativeNode();

    return this.__mountChildrenImpl(this._parent, children, context, function (nativeNode) {
      nativeNode = toArray(nativeNode);

      for (var i = 0; i < nativeNode.length; i++) {
        fragment.push(nativeNode[i]);
      }
    });
  };

  _proto.unmountComponent = function unmountComponent(shouldNotRemoveChild) {
    var nativeNode = this[NATIVE_NODE];

    if (nativeNode) {
      Instance.remove(nativeNode);

      if (!shouldNotRemoveChild) {
        for (var i = 0, l = nativeNode.length; i < l; i++) {
          Host.driver.removeChild(nativeNode[i]);
        }
      }
    } // Do not need remove child when their parent is removed


    this.__unmountChildren(true);

    this.__destoryComponent();
  };

  _proto.__updateComponent = function __updateComponent(prevElement, nextElement, prevContext, nextContext) {
    // Replace current element
    this.__currentElement = nextElement;

    this.__updateChildren(this.__currentElement, nextContext);

    if (process.env.NODE_ENV !== 'production') {
      this.__currentElement.type = FragmentComponent;
      Host.reconciler.receiveComponent(this);
    }
  };

  _proto.__createNativeNode = function __createNativeNode() {
    return [];
  };

  return FragmentComponent;
}(NativeComponent);

if (process.env.NODE_ENV !== 'production') {
  FragmentComponent.displayName = 'Fragment';
}

export default FragmentComponent;

==> rax-1.1.2.tgz: package/es/vdom/fragment.js <==
function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

import Host from './host';
import NativeComponent from './native';
import Instance from './instance';
import toArray from '../toArray';
import { INSTANCE, INTERNAL, NATIVE_NODE } from '../constant';
/**
 * Fragment Component
 */

var FragmentComponent = /*#__PURE__*/function (_NativeComponent) {
  _inheritsLoose(FragmentComponent, _NativeComponent);

  function FragmentComponent() {
    return _NativeComponent.apply(this, arguments) || this;
  }

  var _proto = FragmentComponent.prototype;

  _proto.__mountComponent = function __mountComponent(parent, parentInstance, context, nativeNodeMounter) {
    this.__initComponent(parent, parentInstance, context);

    var instance = this[INSTANCE] = {};
    instance[INTERNAL] = this; // Mount children

    this.__mountChildren(this.__currentElement, context);

    var fragment = this.__getNativeNode();

    if (nativeNodeMounter) {
      nativeNodeMounter(fragment, parent);
    } else {
      for (var i = 0; i < fragment.length; i++) {
        Host.driver.appendChild(fragment[i], parent);
      }
    }

    if (process.env.NODE_ENV !== 'production') {
      this.__currentElement.type = FragmentComponent;
      Host.reconciler.mountComponent(this);
    }

    return instance;
  };

  _proto.__mountChildren = function __mountChildren(children, context) {
    var fragment = this.__getNativeNode();

    return this.__mountChildrenImpl(this._parent, children, context, function (nativeNode) {
      nativeNode = toArray(nativeNode);

      for (var i = 0; i < nativeNode.length; i++) {
        fragment.push(nativeNode[i]);
      }
    });
  };

  _proto.unmountComponent = function unmountComponent(shouldNotRemoveChild) {
    var nativeNode = this[NATIVE_NODE];

    if (nativeNode) {
      Instance.remove(nativeNode);

      if (!shouldNotRemoveChild) {
        for (var i = 0, l = nativeNode.length; i < l; i++) {
          Host.driver.removeChild(nativeNode[i]);
        }
      }
    } // Do not need remove child when their parent is removed


    this.__unmountChildren(true);

    this.__destoryComponent();
  };

  _proto.__updateComponent = function __updateComponent(prevElement, nextElement, prevContext, nextContext) {
    // Replace current element
    this.__currentElement = nextElement;

    this.__updateChildren(this.__currentElement, nextContext);

    if (process.env.NODE_ENV !== 'production') {
      this.__currentElement.type = FragmentComponent;
      Host.reconciler.receiveComponent(this);
    }
  };

  _proto.__createNativeNode = function __createNativeNode() {
    return [];
  };

  return FragmentComponent;
}(NativeComponent);

if (process.env.NODE_ENV !== 'production') {
  FragmentComponent.displayName = 'Fragment';
}

export default FragmentComponent;
